pub fn decode_call_inputs<I: OffsetSizeTrait>(
signature: &str,
data: &GenericBinaryArray<I>,
allow_decode_fail: bool,
large_int_as_binary: bool,
) -> Result<RecordBatch>Expand description
Decodes given call input data in arrow format to arrow format. Output Arrow schema is auto generated based on the function signature. Handles any level of nesting with Lists/Structs.
Writes null for data rows that fail to decode if allow_decode_fail is set to true.
Errors when a row fails to decode if allow_decode_fail is set to false.
When large_int_as_binary is true, signed and unsigned integers wider than
64 bits are emitted as 32-byte big-endian Binary columns (two’s-complement
for signed) instead of Decimal128/Decimal256.